ENDPOINT = "https://api-clientes.goldenergy.pt/api"
LOGIN_PATH = "/user-auth/token"

CONTRACT_PATH = "/contracts/single"
CONTRACT_LIST_PATH = "/contracts/list"
CONSUMPTIONS_PATH = "/consumptions/chart-info"

JSON_CONTENT = "application/json"
DEFAULT_HEADERS = {
    "Content-Type": "application/json; charset=utf-8"
}

AUTH_TOKEN_PREFIX = "Bearer "
AUTH_HEADER = "Authorization"

CODE_PARAM = "code"
PWD_PARAM = "password"

GAS = "GAS"
ELECTRICITY = "ELECTRICITY"
